# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/account_budget_proposal.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import account_budget_proposal_status_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_account__budget__proposal__status__pb2
from google.ads.google_ads.v1.proto.enums import account_budget_proposal_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_account__budget__proposal__type__pb2
from google.ads.google_ads.v1.proto.enums import spending_limit_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_spending__limit__type__pb2
from google.ads.google_ads.v1.proto.enums import time_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/account_budget_proposal.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\032AccountBudgetProposalProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\nEgoogle/ads/googleads_v1/proto/resources/account_budget_proposal.proto\x12!google.ads.googleads.v1.resources\x1aHgoogle/ads/googleads_v1/proto/enums/account_budget_proposal_status.proto\x1a\x46google/ads/googleads_v1/proto/enums/account_budget_proposal_type.proto\x1a=google/ads/googleads_v1/proto/enums/spending_limit_type.proto\x1a\x33google/ads/googleads_v1/proto/enums/time_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xb3\r\n\x15\x41\x63\x63ountBudgetProposal\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\rbilling_setup\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0e\x61\x63\x63ount_budget\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12m\n\rproposal_type\x18\x04 \x01(\x0e\x32V.google.ads.googleads.v1.enums.AccountBudgetProposalTypeEnum.AccountBudgetProposalType\x12j\n\x06status\x18\x0f \x01(\x0e\x32Z.google.ads.googleads.v1.enums.AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus\x12\x33\n\rproposed_name\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12>\n\x18\x61pproved_start_date_time\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x44\n\x1eproposed_purchase_order_number\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0eproposed_notes\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x12\x63reation_date_time\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x12\x61pproval_date_time\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12@\n\x18proposed_start_date_time\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x12X\n\x18proposed_start_time_type\x18\x07 \x01(\x0e\x32\x34.google.ads.googleads.v1.enums.TimeTypeEnum.TimeTypeH\x00\x12>\n\x16proposed_end_date_time\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x01\x12V\n\x16proposed_end_time_type\x18\t \x01(\x0e\x32\x34.google.ads.googleads.v1.enums.TimeTypeEnum.TimeTypeH\x01\x12>\n\x16\x61pproved_end_date_time\x18\x15 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x02\x12V\n\x16\x61pproved_end_time_type\x18\x16 \x01(\x0e\x32\x34.google.ads.googleads.v1.enums.TimeTypeEnum.TimeTypeH\x02\x12\x45\n\x1eproposed_spending_limit_micros\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueH\x03\x12n\n\x1cproposed_spending_limit_type\x18\x0b \x01(\x0e\x32\x46.google.ads.googleads.v1.enums.SpendingLimitTypeEnum.SpendingLimitTypeH\x03\x12\x45\n\x1e\x61pproved_spending_limit_micros\x18\x17 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueH\x04\x12n\n\x1c\x61pproved_spending_limit_type\x18\x18 \x01(\x0e\x32\x46.google.ads.googleads.v1.enums.SpendingLimitTypeEnum.SpendingLimitTypeH\x04\x42\x15\n\x13proposed_start_timeB\x13\n\x11proposed_end_timeB\x13\n\x11\x61pproved_end_timeB\x19\n\x17proposed_spending_limitB\x19\n\x17\x61pproved_spending_limitB\x87\x02\n%com.google.ads.googleads.v1.resourcesB\x1a\x41\x63\x63ountBudgetProposalProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_account__budget__proposal__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_account__budget__proposal__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_spending__limit__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_ACCOUNTBUDGETPROPOSAL = _descriptor.Descriptor(
  name='AccountBudgetProposal',
  full_name='google.ads.googleads.v1.resources.AccountBudgetProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.id', index=1,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='billing_setup', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.billing_setup', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_budget', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.account_budget', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposal_type', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.proposal_type', index=4,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.status', index=5,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_name', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.proposed_name', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approved_start_date_time', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.approved_start_date_time', index=7,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_purchase_order_number', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.proposed_purchase_order_number', index=8,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_notes', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.proposed_notes', index=9,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creation_date_time', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.creation_date_time', index=10,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approval_date_time', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.approval_date_time', index=11,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_start_date_time', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.proposed_start_date_time', index=12,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_start_time_type', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.proposed_start_time_type', index=13,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_end_date_time', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.proposed_end_date_time', index=14,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_end_time_type', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.proposed_end_time_type', index=15,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approved_end_date_time', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.approved_end_date_time', index=16,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approved_end_time_type', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.approved_end_time_type', index=17,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_spending_limit_micros', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.proposed_spending_limit_micros', index=18,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_spending_limit_type', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.proposed_spending_limit_type', index=19,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approved_spending_limit_micros', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.approved_spending_limit_micros', index=20,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approved_spending_limit_type', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.approved_spending_limit_type', index=21,
      number=24, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='proposed_start_time', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.proposed_start_time',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='proposed_end_time', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.proposed_end_time',
      index=1, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='approved_end_time', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.approved_end_time',
      index=2, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='proposed_spending_limit', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.proposed_spending_limit',
      index=3, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='approved_spending_limit', full_name='google.ads.googleads.v1.resources.AccountBudgetProposal.approved_spending_limit',
      index=4, containing_type=None, fields=[]),
  ],
  serialized_start=433,
  serialized_end=2148,
)

_ACCOUNTBUDGETPROPOSAL.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['billing_setup'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['account_budget'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['proposal_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_account__budget__proposal__type__pb2._ACCOUNTBUDGETPROPOSALTYPEENUM_ACCOUNTBUDGETPROPOSALTYPE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_account__budget__proposal__status__pb2._ACCOUNTBUDGETPROPOSALSTATUSENUM_ACCOUNTBUDGETPROPOSALSTATUS
_ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['approved_start_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_purchase_order_number'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_notes'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['creation_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['approval_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_start_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_start_time_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2._TIMETYPEENUM_TIMETYPE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_end_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_end_time_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2._TIMETYPEENUM_TIMETYPE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['approved_end_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['approved_end_time_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2._TIMETYPEENUM_TIMETYPE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_spending_limit_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_spending_limit_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_spending__limit__type__pb2._SPENDINGLIMITTYPEENUM_SPENDINGLIMITTYPE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['approved_spending_limit_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ACCOUNTBUDGETPROPOSAL.fields_by_name['approved_spending_limit_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_spending__limit__type__pb2._SPENDINGLIMITTYPEENUM_SPENDINGLIMITTYPE
_ACCOUNTBUDGETPROPOSAL.oneofs_by_name['proposed_start_time'].fields.append(
  _ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_start_date_time'])
_ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_start_date_time'].containing_oneof = _ACCOUNTBUDGETPROPOSAL.oneofs_by_name['proposed_start_time']
_ACCOUNTBUDGETPROPOSAL.oneofs_by_name['proposed_start_time'].fields.append(
  _ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_start_time_type'])
_ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_start_time_type'].containing_oneof = _ACCOUNTBUDGETPROPOSAL.oneofs_by_name['proposed_start_time']
_ACCOUNTBUDGETPROPOSAL.oneofs_by_name['proposed_end_time'].fields.append(
  _ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_end_date_time'])
_ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_end_date_time'].containing_oneof = _ACCOUNTBUDGETPROPOSAL.oneofs_by_name['proposed_end_time']
_ACCOUNTBUDGETPROPOSAL.oneofs_by_name['proposed_end_time'].fields.append(
  _ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_end_time_type'])
_ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_end_time_type'].containing_oneof = _ACCOUNTBUDGETPROPOSAL.oneofs_by_name['proposed_end_time']
_ACCOUNTBUDGETPROPOSAL.oneofs_by_name['approved_end_time'].fields.append(
  _ACCOUNTBUDGETPROPOSAL.fields_by_name['approved_end_date_time'])
_ACCOUNTBUDGETPROPOSAL.fields_by_name['approved_end_date_time'].containing_oneof = _ACCOUNTBUDGETPROPOSAL.oneofs_by_name['approved_end_time']
_ACCOUNTBUDGETPROPOSAL.oneofs_by_name['approved_end_time'].fields.append(
  _ACCOUNTBUDGETPROPOSAL.fields_by_name['approved_end_time_type'])
_ACCOUNTBUDGETPROPOSAL.fields_by_name['approved_end_time_type'].containing_oneof = _ACCOUNTBUDGETPROPOSAL.oneofs_by_name['approved_end_time']
_ACCOUNTBUDGETPROPOSAL.oneofs_by_name['proposed_spending_limit'].fields.append(
  _ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_spending_limit_micros'])
_ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_spending_limit_micros'].containing_oneof = _ACCOUNTBUDGETPROPOSAL.oneofs_by_name['proposed_spending_limit']
_ACCOUNTBUDGETPROPOSAL.oneofs_by_name['proposed_spending_limit'].fields.append(
  _ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_spending_limit_type'])
_ACCOUNTBUDGETPROPOSAL.fields_by_name['proposed_spending_limit_type'].containing_oneof = _ACCOUNTBUDGETPROPOSAL.oneofs_by_name['proposed_spending_limit']
_ACCOUNTBUDGETPROPOSAL.oneofs_by_name['approved_spending_limit'].fields.append(
  _ACCOUNTBUDGETPROPOSAL.fields_by_name['approved_spending_limit_micros'])
_ACCOUNTBUDGETPROPOSAL.fields_by_name['approved_spending_limit_micros'].containing_oneof = _ACCOUNTBUDGETPROPOSAL.oneofs_by_name['approved_spending_limit']
_ACCOUNTBUDGETPROPOSAL.oneofs_by_name['approved_spending_limit'].fields.append(
  _ACCOUNTBUDGETPROPOSAL.fields_by_name['approved_spending_limit_type'])
_ACCOUNTBUDGETPROPOSAL.fields_by_name['approved_spending_limit_type'].containing_oneof = _ACCOUNTBUDGETPROPOSAL.oneofs_by_name['approved_spending_limit']
DESCRIPTOR.message_types_by_name['AccountBudgetProposal'] = _ACCOUNTBUDGETPROPOSAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AccountBudgetProposal = _reflection.GeneratedProtocolMessageType('AccountBudgetProposal', (_message.Message,), dict(
  DESCRIPTOR = _ACCOUNTBUDGETPROPOSAL,
  __module__ = 'google.ads.googleads_v1.proto.resources.account_budget_proposal_pb2'
  ,
  __doc__ = """An account-level budget proposal.
  
  All fields prefixed with 'proposed' may not necessarily be applied
  directly. For example, proposed spending limits may be adjusted before
  their application. This is true if the 'proposed' field has an
  'approved' counterpart, e.g. spending limits.
  
  Please note that the proposal type (proposal\_type) changes which fields
  are required and which must remain empty.
  
  
  Attributes:
      resource_name:
          The resource name of the proposal. AccountBudgetProposal
          resource names have the form:  ``customers/{customer_id}/accou
          ntBudgetProposals/{account_budget_proposal_id}``
      id:
          The ID of the proposal.
      billing_setup:
          The resource name of the billing setup associated with this
          proposal.
      account_budget:
          The resource name of the account-level budget associated with
          this proposal.
      proposal_type:
          The type of this proposal, e.g. END to end the budget
          associated with this proposal.
      status:
          The status of this proposal. When a new proposal is created,
          the status defaults to PENDING.
      proposed_name:
          The name to assign to the account-level budget.
      approved_start_date_time:
          The approved start date time in yyyy-mm-dd hh:mm:ss format.
      proposed_purchase_order_number:
          A purchase order number is a value that enables the user to
          help them reference this budget in their monthly invoices.
      proposed_notes:
          Notes associated with this budget.
      creation_date_time:
          The date time when this account-level budget proposal was
          created, which is not the same as its approval date time, if
          applicable.
      approval_date_time:
          The date time when this account-level budget was approved, if
          applicable.
      proposed_start_time:
          The proposed start date time of the account-level budget,
          which cannot be in the past.
      proposed_start_date_time:
          The proposed start date time in yyyy-mm-dd hh:mm:ss format.
      proposed_start_time_type:
          The proposed start date time as a well-defined type, e.g. NOW.
      proposed_end_time:
          The proposed end date time of the account-level budget, which
          cannot be in the past.
      proposed_end_date_time:
          The proposed end date time in yyyy-mm-dd hh:mm:ss format.
      proposed_end_time_type:
          The proposed end date time as a well-defined type, e.g.
          FOREVER.
      approved_end_time:
          The approved end date time of the account-level budget.
      approved_end_date_time:
          The approved end date time in yyyy-mm-dd hh:mm:ss format.
      approved_end_time_type:
          The approved end date time as a well-defined type, e.g.
          FOREVER.
      proposed_spending_limit:
          The proposed spending limit.
      proposed_spending_limit_micros:
          The proposed spending limit in micros. One million is
          equivalent to one unit.
      proposed_spending_limit_type:
          The proposed spending limit as a well-defined type, e.g.
          INFINITE.
      approved_spending_limit:
          The approved spending limit.
      approved_spending_limit_micros:
          The approved spending limit in micros. One million is
          equivalent to one unit.
      approved_spending_limit_type:
          The approved spending limit as a well-defined type, e.g.
          INFINITE.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.AccountBudgetProposal)
  ))
_sym_db.RegisterMessage(AccountBudgetProposal)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/services/billing_setup_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.resources import billing_setup_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_billing__setup__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/services/billing_setup_service.proto',
  package='google.ads.googleads.v1.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v1.servicesB\030BillingSetupServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V1.Services\312\002 Google\\Ads\\GoogleAds\\V1\\Services\352\002$Google::Ads::GoogleAds::V1::Services'),
  serialized_pb=_b('\nBgoogle/ads/googleads_v1/proto/services/billing_setup_service.proto\x12 google.ads.googleads.v1.services\x1a;google/ads/googleads_v1/proto/resources/billing_setup.proto\x1a\x1cgoogle/api/annotations.proto\"/\n\x16GetBillingSetupRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"|\n\x19MutateBillingSetupRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12J\n\toperation\x18\x02 \x01(\x0b\x32\x37.google.ads.googleads.v1.services.BillingSetupOperation\"y\n\x15\x42illingSetupOperation\x12\x41\n\x06\x63reate\x18\x02 \x01(\x0b\x32/.google.ads.googleads.v1.resources.BillingSetupH\x00\x12\x10\n\x06remove\x18\x01 \x01(\tH\x00\x42\x0b\n\toperation\"h\n\x1aMutateBillingSetupResponse\x12J\n\x06result\x18\x01 \x01(\x0b\x32:.google.ads.googleads.v1.services.MutateBillingSetupResult\"1\n\x18MutateBillingSetupResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\x9e\x03\n\x13\x42illingSetupService\x12\xb5\x01\n\x0fGetBillingSetup\x12\x38.google.ads.googleads.v1.services.GetBillingSetupRequest\x1a/.google.ads.googleads.v1.resources.BillingSetup\"7\x82\xd3\xe4\x93\x02\x31\x12//v1/{resource_name=customers/*/billingSetups/*}\x12\xce\x01\n\x12MutateBillingSetup\x12;.google.ads.googleads.v1.services.MutateBillingSetupRequest\x1a<.google.ads.googleads.v1.services.MutateBillingSetupResponse\"=\x82\xd3\xe4\x93\x02\x37\"2/v1/customers/{customer_id=*}/billingSetups:mutate:\x01*B\xff\x01\n$com.google.ads.googleads.v1.servicesB\x18\x42illingSetupServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V1.Services\xca\x02 Google\\Ads\\GoogleAds\\V1\\Services\xea\x02$Google::Ads::GoogleAds::V1::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_billing__setup__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GETBILLINGSETUPREQUEST = _descriptor.Descriptor(
  name='GetBillingSetupRequest',
  full_name='google.ads.googleads.v1.services.GetBillingSetupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.GetBillingSetupRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=195,
  serialized_end=242,
)


_MUTATEBILLINGSETUPREQUEST = _descriptor.Descriptor(
  name='MutateBillingSetupRequest',
  full_name='google.ads.googleads.v1.services.MutateBillingSetupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v1.services.MutateBillingSetupRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operation', full_name='google.ads.googleads.v1.services.MutateBillingSetupRequest.operation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=368,
)


_BILLINGSETUPOPERATION = _descriptor.Descriptor(
  name='BillingSetupOperation',
  full_name='google.ads.googleads.v1.services.BillingSetupOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v1.services.BillingSetupOperation.create', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v1.services.BillingSetupOperation.remove', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v1.services.BillingSetupOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=370,
  serialized_end=491,
)


_MUTATEBILLINGSETUPRESPONSE = _descriptor.Descriptor(
  name='MutateBillingSetupResponse',
  full_name='google.ads.googleads.v1.services.MutateBillingSetupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='google.ads.googleads.v1.services.MutateBillingSetupResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=493,
  serialized_end=597,
)


_MUTATEBILLINGSETUPRESULT = _descriptor.Descriptor(
  name='MutateBillingSetupResult',
  full_name='google.ads.googleads.v1.services.MutateBillingSetupResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.MutateBillingSetupResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=599,
  serialized_end=648,
)

_MUTATEBILLINGSETUPREQUEST.fields_by_name['operation'].message_type = _BILLINGSETUPOPERATION
_BILLINGSETUPOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_billing__setup__pb2._BILLINGSETUP
_BILLINGSETUPOPERATION.oneofs_by_name['operation'].fields.append(
  _BILLINGSETUPOPERATION.fields_by_name['create'])
_BILLINGSETUPOPERATION.fields_by_name['create'].containing_oneof = _BILLINGSETUPOPERATION.oneofs_by_name['operation']
_BILLINGSETUPOPERATION.oneofs_by_name['operation'].fields.append(
  _BILLINGSETUPOPERATION.fields_by_name['remove'])
_BILLINGSETUPOPERATION.fields_by_name['remove'].containing_oneof = _BILLINGSETUPOPERATION.oneofs_by_name['operation']
_MUTATEBILLINGSETUPRESPONSE.fields_by_name['result'].message_type = _MUTATEBILLINGSETUPRESULT
DESCRIPTOR.message_types_by_name['GetBillingSetupRequest'] = _GETBILLINGSETUPREQUEST
DESCRIPTOR.message_types_by_name['MutateBillingSetupRequest'] = _MUTATEBILLINGSETUPREQUEST
DESCRIPTOR.message_types_by_name['BillingSetupOperation'] = _BILLINGSETUPOPERATION
DESCRIPTOR.message_types_by_name['MutateBillingSetupResponse'] = _MUTATEBILLINGSETUPRESPONSE
DESCRIPTOR.message_types_by_name['MutateBillingSetupResult'] = _MUTATEBILLINGSETUPRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetBillingSetupRequest = _reflection.GeneratedProtocolMessageType('GetBillingSetupRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBILLINGSETUPREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.billing_setup_service_pb2'
  ,
  __doc__ = """Request message for
  [BillingSetupService.GetBillingSetup][google.ads.googleads.v1.services.BillingSetupService.GetBillingSetup].
  
  
  Attributes:
      resource_name:
          The resource name of the billing setup to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GetBillingSetupRequest)
  ))
_sym_db.RegisterMessage(GetBillingSetupRequest)

MutateBillingSetupRequest = _reflection.GeneratedProtocolMessageType('MutateBillingSetupRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEBILLINGSETUPREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.billing_setup_service_pb2'
  ,
  __doc__ = """Request message for billing setup mutate operations.
  
  
  Attributes:
      customer_id:
          Id of the customer to apply the billing setup mutate operation
          to.
      operation:
          The operation to perform.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateBillingSetupRequest)
  ))
_sym_db.RegisterMessage(MutateBillingSetupRequest)

BillingSetupOperation = _reflection.GeneratedProtocolMessageType('BillingSetupOperation', (_message.Message,), dict(
  DESCRIPTOR = _BILLINGSETUPOPERATION,
  __module__ = 'google.ads.googleads_v1.proto.services.billing_setup_service_pb2'
  ,
  __doc__ = """A single operation on a billing setup, which describes the cancellation
  of an existing billing setup.
  
  
  Attributes:
      operation:
          Only one of these operations can be set. "Update" operations
          are not supported.
      create:
          Creates a billing setup. No resource name is expected for the
          new billing setup.
      remove:
          Resource name of the billing setup to remove. A setup cannot
          be removed unless it is in a pending state or its scheduled
          start time is in the future. The resource name looks like
          ``customers/{customer_id}/billingSetups/{billing_id}``.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.BillingSetupOperation)
  ))
_sym_db.RegisterMessage(BillingSetupOperation)

MutateBillingSetupResponse = _reflection.GeneratedProtocolMessageType('MutateBillingSetupResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEBILLINGSETUPRESPONSE,
  __module__ = 'google.ads.googleads_v1.proto.services.billing_setup_service_pb2'
  ,
  __doc__ = """Response message for a billing setup operation.
  
  
  Attributes:
      result:
          A result that identifies the resource affected by the mutate
          request.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateBillingSetupResponse)
  ))
_sym_db.RegisterMessage(MutateBillingSetupResponse)

MutateBillingSetupResult = _reflection.GeneratedProtocolMessageType('MutateBillingSetupResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEBILLINGSETUPRESULT,
  __module__ = 'google.ads.googleads_v1.proto.services.billing_setup_service_pb2'
  ,
  __doc__ = """Result for a single billing setup mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateBillingSetupResult)
  ))
_sym_db.RegisterMessage(MutateBillingSetupResult)


DESCRIPTOR._options = None

_BILLINGSETUPSERVICE = _descriptor.ServiceDescriptor(
  name='BillingSetupService',
  full_name='google.ads.googleads.v1.services.BillingSetupService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=651,
  serialized_end=1065,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetBillingSetup',
    full_name='google.ads.googleads.v1.services.BillingSetupService.GetBillingSetup',
    index=0,
    containing_service=None,
    input_type=_GETBILLINGSETUPREQUEST,
    output_type=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_billing__setup__pb2._BILLINGSETUP,
    serialized_options=_b('\202\323\344\223\0021\022//v1/{resource_name=customers/*/billingSetups/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='MutateBillingSetup',
    full_name='google.ads.googleads.v1.services.BillingSetupService.MutateBillingSetup',
    index=1,
    containing_service=None,
    input_type=_MUTATEBILLINGSETUPREQUEST,
    output_type=_MUTATEBILLINGSETUPRESPONSE,
    serialized_options=_b('\202\323\344\223\0027\"2/v1/customers/{customer_id=*}/billingSetups:mutate:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_BILLINGSETUPSERVICE)

DESCRIPTOR.services_by_name['BillingSetupService'] = _BILLINGSETUPSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v1.proto.resources import label_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_label__pb2
from google.ads.google_ads.v1.proto.services import label_service_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_label__service__pb2


class LabelServiceStub(object):
  """Service to manage labels.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetLabel = channel.unary_unary(
        '/google.ads.googleads.v1.services.LabelService/GetLabel',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_label__service__pb2.GetLabelRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_label__pb2.Label.FromString,
        )
    self.MutateLabels = channel.unary_unary(
        '/google.ads.googleads.v1.services.LabelService/MutateLabels',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_label__service__pb2.MutateLabelsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_label__service__pb2.MutateLabelsResponse.FromString,
        )


class LabelServiceServicer(object):
  """Service to manage labels.
  """

  def GetLabel(self, request, context):
    """Returns the requested label in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateLabels(self, request, context):
    """Creates, updates, or removes labels. Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_LabelServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetLabel': grpc.unary_unary_rpc_method_handler(
          servicer.GetLabel,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_label__service__pb2.GetLabelRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_label__pb2.Label.SerializeToString,
      ),
      'MutateLabels': grpc.unary_unary_rpc_method_handler(
          servicer.MutateLabels,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_label__service__pb2.MutateLabelsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_label__service__pb2.MutateLabelsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v1.services.LabelService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/feed_mapping.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.enums import ad_customizer_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__customizer__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import affiliate_location_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_affiliate__location__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import app_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_app__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import call_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_call__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import callout_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_callout__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import custom_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_custom__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import dsa_page_feed_criterion_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_dsa__page__feed__criterion__field__pb2
from google.ads.google_ads.v2.proto.enums import education_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_education__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import feed_mapping_criterion_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__mapping__criterion__type__pb2
from google.ads.google_ads.v2.proto.enums import feed_mapping_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__mapping__status__pb2
from google.ads.google_ads.v2.proto.enums import flight_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_flight__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import hotel_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import job_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_job__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import local_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_local__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import location_extension_targeting_criterion_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_location__extension__targeting__criterion__field__pb2
from google.ads.google_ads.v2.proto.enums import location_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_location__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import message_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_message__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import placeholder_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placeholder__type__pb2
from google.ads.google_ads.v2.proto.enums import price_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_price__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import promotion_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_promotion__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import real_estate_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_real__estate__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import sitelink_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_sitelink__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import structured_snippet_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_structured__snippet__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import travel_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_travel__placeholder__field__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/feed_mapping.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\020FeedMappingProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n:google/ads/googleads_v2/proto/resources/feed_mapping.proto\x12!google.ads.googleads.v2.resources\x1aIgoogle/ads/googleads_v2/proto/enums/ad_customizer_placeholder_field.proto\x1aNgoogle/ads/googleads_v2/proto/enums/affiliate_location_placeholder_field.proto\x1a?google/ads/googleads_v2/proto/enums/app_placeholder_field.proto\x1a@google/ads/googleads_v2/proto/enums/call_placeholder_field.proto\x1a\x43google/ads/googleads_v2/proto/enums/callout_placeholder_field.proto\x1a\x42google/ads/googleads_v2/proto/enums/custom_placeholder_field.proto\x1aGgoogle/ads/googleads_v2/proto/enums/dsa_page_feed_criterion_field.proto\x1a\x45google/ads/googleads_v2/proto/enums/education_placeholder_field.proto\x1a\x45google/ads/googleads_v2/proto/enums/feed_mapping_criterion_type.proto\x1a=google/ads/googleads_v2/proto/enums/feed_mapping_status.proto\x1a\x42google/ads/googleads_v2/proto/enums/flight_placeholder_field.proto\x1a\x41google/ads/googleads_v2/proto/enums/hotel_placeholder_field.proto\x1a?google/ads/googleads_v2/proto/enums/job_placeholder_field.proto\x1a\x41google/ads/googleads_v2/proto/enums/local_placeholder_field.proto\x1aVgoogle/ads/googleads_v2/proto/enums/location_extension_targeting_criterion_field.proto\x1a\x44google/ads/googleads_v2/proto/enums/location_placeholder_field.proto\x1a\x43google/ads/googleads_v2/proto/enums/message_placeholder_field.proto\x1a:google/ads/googleads_v2/proto/enums/placeholder_type.proto\x1a\x41google/ads/googleads_v2/proto/enums/price_placeholder_field.proto\x1a\x45google/ads/googleads_v2/proto/enums/promotion_placeholder_field.proto\x1aGgoogle/ads/googleads_v2/proto/enums/real_estate_placeholder_field.proto\x1a\x44google/ads/googleads_v2/proto/enums/sitelink_placeholder_field.proto\x1aNgoogle/ads/googleads_v2/proto/enums/structured_snippet_placeholder_field.proto\x1a\x42google/ads/googleads_v2/proto/enums/travel_placeholder_field.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xde\x03\n\x0b\x46\x65\x65\x64Mapping\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12*\n\x04\x66\x65\x65\x64\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Z\n\x18\x61ttribute_field_mappings\x18\x05 \x03(\x0b\x32\x38.google.ads.googleads.v2.resources.AttributeFieldMapping\x12V\n\x06status\x18\x06 \x01(\x0e\x32\x46.google.ads.googleads.v2.enums.FeedMappingStatusEnum.FeedMappingStatus\x12^\n\x10placeholder_type\x18\x03 \x01(\x0e\x32\x42.google.ads.googleads.v2.enums.PlaceholderTypeEnum.PlaceholderTypeH\x00\x12n\n\x0e\x63riterion_type\x18\x04 \x01(\x0e\x32T.google.ads.googleads.v2.enums.FeedMappingCriterionTypeEnum.FeedMappingCriterionTypeH\x00\x42\x08\n\x06target\"\xea\x13\n\x15\x41ttributeFieldMapping\x12\x36\n\x11\x66\x65\x65\x64_attribute_id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12-\n\x08\x66ield_id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12n\n\x0esitelink_field\x18\x03 \x01(\x0e\x32T.google.ads.googleads.v2.enums.SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldH\x00\x12\x62\n\ncall_field\x18\x04 \x01(\x0e\x32L.google.ads.googleads.v2.enums.CallPlaceholderFieldEnum.CallPlaceholderFieldH\x00\x12_\n\tapp_field\x18\x05 \x01(\x0e\x32J.google.ads.googleads.v2.enums.AppPlaceholderFieldEnum.AppPlaceholderFieldH\x00\x12n\n\x0elocation_field\x18\x06 \x01(\x0e\x32T.google.ads.googleads.v2.enums.LocationPlaceholderFieldEnum.LocationPlaceholderFieldH\x00\x12\x8a\x01\n\x18\x61\x66\x66iliate_location_field\x18\x07 \x01(\x0e\x32\x66.google.ads.googleads.v2.enums.AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldH\x00\x12k\n\rcallout_field\x18\x08 \x01(\x0e\x32R.google.ads.googleads.v2.enums.CalloutPlaceholderFieldEnum.CalloutPlaceholderFieldH\x00\x12\x8a\x01\n\x18structured_snippet_field\x18\t \x01(\x0e\x32\x66.google.ads.googleads.v2.enums.StructuredSnippetPlaceholderFieldEnum.StructuredSnippetPlaceholderFieldH\x00\x12k\n\rmessage_field\x18\n \x01(\x0e\x32R.google.ads.googleads.v2.enums.MessagePlaceholderFieldEnum.MessagePlaceholderFieldH\x00\x12\x65\n\x0bprice_field\x18\x0b \x01(\x0e\x32N.google.ads.googleads.v2.enums.PricePlaceholderFieldEnum.PricePlaceholderFieldH\x00\x12q\n\x0fpromotion_field\x18\x0c \x01(\x0e\x32V.google.ads.googleads.v2.enums.PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldH\x00\x12{\n\x13\x61\x64_customizer_field\x18\r \x01(\x0e\x32\\.google.ads.googleads.v2.enums.AdCustomizerPlaceholderFieldEnum.AdCustomizerPlaceholderFieldH\x00\x12u\n\x13\x64sa_page_feed_field\x18\x0e \x01(\x0e\x32V.google.ads.googleads.v2.enums.DsaPageFeedCriterionFieldEnum.DsaPageFeedCriterionFieldH\x00\x12\xa2\x01\n\"location_extension_targeting_field\x18\x0f \x01(\x0e\x32t.google.ads.googleads.v2.enums.LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldH\x00\x12q\n\x0f\x65\x64ucation_field\x18\x10 \x01(\x0e\x32V.google.ads.googleads.v2.enums.EducationPlaceholderFieldEnum.EducationPlaceholderFieldH\x00\x12h\n\x0c\x66light_field\x18\x11 \x01(\x0e\x32P.google.ads.googleads.v2.enums.FlightPlaceholderFieldEnum.FlightPlaceholderFieldH\x00\x12h\n\x0c\x63ustom_field\x18\x12 \x01(\x0e\x32P.google.ads.googleads.v2.enums.CustomPlaceholderFieldEnum.CustomPlaceholderFieldH\x00\x12\x65\n\x0bhotel_field\x18\x13 \x01(\x0e\x32N.google.ads.googleads.v2.enums.HotelPlaceholderFieldEnum.HotelPlaceholderFieldH\x00\x12u\n\x11real_estate_field\x18\x14 \x01(\x0e\x32X.google.ads.googleads.v2.enums.RealEstatePlaceholderFieldEnum.RealEstatePlaceholderFieldH\x00\x12h\n\x0ctravel_field\x18\x15 \x01(\x0e\x32P.google.ads.googleads.v2.enums.TravelPlaceholderFieldEnum.TravelPlaceholderFieldH\x00\x12\x65\n\x0blocal_field\x18\x16 \x01(\x0e\x32N.google.ads.googleads.v2.enums.LocalPlaceholderFieldEnum.LocalPlaceholderFieldH\x00\x12_\n\tjob_field\x18\x17 \x01(\x0e\x32J.google.ads.googleads.v2.enums.JobPlaceholderFieldEnum.JobPlaceholderFieldH\x00\x42\x07\n\x05\x66ieldB\xfd\x01\n%com.google.ads.googleads.v2.resourcesB\x10\x46\x65\x65\x64MappingProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__customizer__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_affiliate__location__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_app__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_call__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_callout__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_custom__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_dsa__page__feed__criterion__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_education__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__mapping__criterion__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__mapping__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_flight__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_job__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_local__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_location__extension__targeting__criterion__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_location__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_message__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placeholder__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_price__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_promotion__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_real__estate__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_sitelink__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_structured__snippet__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_travel__placeholder__field__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_FEEDMAPPING = _descriptor.Descriptor(
  name='FeedMapping',
  full_name='google.ads.googleads.v2.resources.FeedMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.FeedMapping.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed', full_name='google.ads.googleads.v2.resources.FeedMapping.feed', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_field_mappings', full_name='google.ads.googleads.v2.resources.FeedMapping.attribute_field_mappings', index=2,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v2.resources.FeedMapping.status', index=3,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placeholder_type', full_name='google.ads.googleads.v2.resources.FeedMapping.placeholder_type', index=4,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='criterion_type', full_name='google.ads.googleads.v2.resources.FeedMapping.criterion_type', index=5,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='target', full_name='google.ads.googleads.v2.resources.FeedMapping.target',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1844,
  serialized_end=2322,
)


_ATTRIBUTEFIELDMAPPING = _descriptor.Descriptor(
  name='AttributeFieldMapping',
  full_name='google.ads.googleads.v2.resources.AttributeFieldMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_attribute_id', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.feed_attribute_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_id', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.field_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sitelink_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.sitelink_field', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.call_field', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.app_field', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.location_field', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='affiliate_location_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.affiliate_location_field', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='callout_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.callout_field', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='structured_snippet_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.structured_snippet_field', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.message_field', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.price_field', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='promotion_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.promotion_field', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_customizer_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.ad_customizer_field', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dsa_page_feed_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.dsa_page_feed_field', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_extension_targeting_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.location_extension_targeting_field', index=14,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='education_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.education_field', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flight_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.flight_field', index=16,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.custom_field', index=17,
      number=18, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.hotel_field', index=18,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='real_estate_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.real_estate_field', index=19,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='travel_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.travel_field', index=20,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.local_field', index=21,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.job_field', index=22,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.field',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2325,
  serialized_end=4863,
)

_FEEDMAPPING.fields_by_name['feed'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDMAPPING.fields_by_name['attribute_field_mappings'].message_type = _ATTRIBUTEFIELDMAPPING
_FEEDMAPPING.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__mapping__status__pb2._FEEDMAPPINGSTATUSENUM_FEEDMAPPINGSTATUS
_FEEDMAPPING.fields_by_name['placeholder_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placeholder__type__pb2._PLACEHOLDERTYPEENUM_PLACEHOLDERTYPE
_FEEDMAPPING.fields_by_name['criterion_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__mapping__criterion__type__pb2._FEEDMAPPINGCRITERIONTYPEENUM_FEEDMAPPINGCRITERIONTYPE
_FEEDMAPPING.oneofs_by_name['target'].fields.append(
  _FEEDMAPPING.fields_by_name['placeholder_type'])
_FEEDMAPPING.fields_by_name['placeholder_type'].containing_oneof = _FEEDMAPPING.oneofs_by_name['target']
_FEEDMAPPING.oneofs_by_name['target'].fields.append(
  _FEEDMAPPING.fields_by_name['criterion_type'])
_FEEDMAPPING.fields_by_name['criterion_type'].containing_oneof = _FEEDMAPPING.oneofs_by_name['target']
_ATTRIBUTEFIELDMAPPING.fields_by_name['feed_attribute_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ATTRIBUTEFIELDMAPPING.fields_by_name['field_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ATTRIBUTEFIELDMAPPING.fields_by_name['sitelink_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_sitelink__placeholder__field__pb2._SITELINKPLACEHOLDERFIELDENUM_SITELINKPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['call_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_call__placeholder__field__pb2._CALLPLACEHOLDERFIELDENUM_CALLPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['app_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_app__placeholder__field__pb2._APPPLACEHOLDERFIELDENUM_APPPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['location_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_location__placeholder__field__pb2._LOCATIONPLACEHOLDERFIELDENUM_LOCATIONPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['affiliate_location_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_affiliate__location__placeholder__field__pb2._AFFILIATELOCATIONPLACEHOLDERFIELDENUM_AFFILIATELOCATIONPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['callout_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_callout__placeholder__field__pb2._CALLOUTPLACEHOLDERFIELDENUM_CALLOUTPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['structured_snippet_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_structured__snippet__placeholder__field__pb2._STRUCTUREDSNIPPETPLACEHOLDERFIELDENUM_STRUCTUREDSNIPPETPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['message_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_message__placeholder__field__pb2._MESSAGEPLACEHOLDERFIELDENUM_MESSAGEPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['price_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_price__placeholder__field__pb2._PRICEPLACEHOLDERFIELDENUM_PRICEPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['promotion_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_promotion__placeholder__field__pb2._PROMOTIONPLACEHOLDERFIELDENUM_PROMOTIONPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['ad_customizer_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__customizer__placeholder__field__pb2._ADCUSTOMIZERPLACEHOLDERFIELDENUM_ADCUSTOMIZERPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['dsa_page_feed_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_dsa__page__feed__criterion__field__pb2._DSAPAGEFEEDCRITERIONFIELDENUM_DSAPAGEFEEDCRITERIONFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['location_extension_targeting_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_location__extension__targeting__criterion__field__pb2._LOCATIONEXTENSIONTARGETINGCRITERIONFIELDENUM_LOCATIONEXTENSIONTARGETINGCRITERIONFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['education_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_education__placeholder__field__pb2._EDUCATIONPLACEHOLDERFIELDENUM_EDUCATIONPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['flight_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_flight__placeholder__field__pb2._FLIGHTPLACEHOLDERFIELDENUM_FLIGHTPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['custom_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_custom__placeholder__field__pb2._CUSTOMPLACEHOLDERFIELDENUM_CUSTOMPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['hotel_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__placeholder__field__pb2._HOTELPLACEHOLDERFIELDENUM_HOTELPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['real_estate_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_real__estate__placeholder__field__pb2._REALESTATEPLACEHOLDERFIELDENUM_REALESTATEPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['travel_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_travel__placeholder__field__pb2._TRAVELPLACEHOLDERFIELDENUM_TRAVELPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['local_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_local__placeholder__field__pb2._LOCALPLACEHOLDERFIELDENUM_LOCALPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['job_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_job__placeholder__field__pb2._JOBPLACEHOLDERFIELDENUM_JOBPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['sitelink_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['sitelink_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['call_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['call_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['app_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['app_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['location_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['location_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['affiliate_location_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['affiliate_location_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['callout_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['callout_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['structured_snippet_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['structured_snippet_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['message_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['message_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['price_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['price_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['promotion_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['promotion_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['ad_customizer_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['ad_customizer_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['dsa_page_feed_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['dsa_page_feed_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['location_extension_targeting_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['location_extension_targeting_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['education_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['education_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['flight_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['flight_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['custom_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['custom_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['hotel_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['hotel_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['real_estate_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['real_estate_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['travel_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['travel_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['local_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['local_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['job_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['job_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
DESCRIPTOR.message_types_by_name['FeedMapping'] = _FEEDMAPPING
DESCRIPTOR.message_types_by_name['AttributeFieldMapping'] = _ATTRIBUTEFIELDMAPPING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedMapping = _reflection.GeneratedProtocolMessageType('FeedMapping', (_message.Message,), dict(
  DESCRIPTOR = _FEEDMAPPING,
  __module__ = 'google.ads.googleads_v2.proto.resources.feed_mapping_pb2'
  ,
  __doc__ = """A feed mapping.
  
  
  Attributes:
      resource_name:
          The resource name of the feed mapping. Feed mapping resource
          names have the form:  ``customers/{customer_id}/feedMappings/{
          feed_id}~{feed_mapping_id}``
      feed:
          The feed of this feed mapping.
      attribute_field_mappings:
          Feed attributes to field mappings. These mappings are a one-
          to-many relationship meaning that 1 feed attribute can be used
          to populate multiple placeholder fields, but 1 placeholder
          field can only draw data from 1 feed attribute. Ad Customizer
          is an exception, 1 placeholder field can be mapped to multiple
          feed attributes. Required.
      status:
          Status of the feed mapping. This field is read-only.
      target:
          Feed mapping target. Can be either a placeholder or a
          criterion. For a given feed, the active FeedMappings must have
          unique targets. Required.
      placeholder_type:
          The placeholder type of this mapping (i.e., if the mapping
          maps feed attributes to placeholder fields).
      criterion_type:
          The criterion type of this mapping (i.e., if the mapping maps
          feed attributes to criterion fields).
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.FeedMapping)
  ))
_sym_db.RegisterMessage(FeedMapping)

AttributeFieldMapping = _reflection.GeneratedProtocolMessageType('AttributeFieldMapping', (_message.Message,), dict(
  DESCRIPTOR = _ATTRIBUTEFIELDMAPPING,
  __module__ = 'google.ads.googleads_v2.proto.resources.feed_mapping_pb2'
  ,
  __doc__ = """Maps from feed attribute id to a placeholder or criterion field id.
  
  
  Attributes:
      feed_attribute_id:
          Feed attribute from which to map.
      field_id:
          The placeholder field ID. If a placeholder field enum is not
          published in the current API version, then this field will be
          populated and the field oneof will be empty. This field is
          read-only.
      field:
          Placeholder or criterion field to be populated using data from
          the above feed attribute. Required.
      sitelink_field:
          Sitelink Placeholder Fields.
      call_field:
          Call Placeholder Fields.
      app_field:
          App Placeholder Fields.
      location_field:
          Location Placeholder Fields. This field is read-only.
      affiliate_location_field:
          Affiliate Location Placeholder Fields. This field is read-
          only.
      callout_field:
          Callout Placeholder Fields.
      structured_snippet_field:
          Structured Snippet Placeholder Fields.
      message_field:
          Message Placeholder Fields.
      price_field:
          Price Placeholder Fields.
      promotion_field:
          Promotion Placeholder Fields.
      ad_customizer_field:
          Ad Customizer Placeholder Fields
      dsa_page_feed_field:
          Dynamic Search Ad Page Feed Fields.
      location_extension_targeting_field:
          Location Target Fields.
      education_field:
          Education Placeholder Fields
      flight_field:
          Flight Placeholder Fields
      custom_field:
          Custom Placeholder Fields
      hotel_field:
          Hotel Placeholder Fields
      real_estate_field:
          Real Estate Placeholder Fields
      travel_field:
          Travel Placeholder Fields
      local_field:
          Local Placeholder Fields
      job_field:
          Job Placeholder Fields
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.AttributeFieldMapping)
  ))
_sym_db.RegisterMessage(AttributeFieldMapping)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/ad_parameter.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/ad_parameter.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\020AdParameterProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\n:google/ads/googleads_v1/proto/resources/ad_parameter.proto\x12!google.ads.googleads.v1.resources\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xca\x01\n\x0b\x41\x64Parameter\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\x38\n\x12\x61\x64_group_criterion\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0fparameter_index\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x34\n\x0einsertion_text\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\xfd\x01\n%com.google.ads.googleads.v1.resourcesB\x10\x41\x64ParameterProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_ADPARAMETER = _descriptor.Descriptor(
  name='AdParameter',
  full_name='google.ads.googleads.v1.resources.AdParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.AdParameter.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_criterion', full_name='google.ads.googleads.v1.resources.AdParameter.ad_group_criterion', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter_index', full_name='google.ads.googleads.v1.resources.AdParameter.parameter_index', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insertion_text', full_name='google.ads.googleads.v1.resources.AdParameter.insertion_text', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=362,
)

_ADPARAMETER.fields_by_name['ad_group_criterion'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADPARAMETER.fields_by_name['parameter_index'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ADPARAMETER.fields_by_name['insertion_text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['AdParameter'] = _ADPARAMETER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdParameter = _reflection.GeneratedProtocolMessageType('AdParameter', (_message.Message,), dict(
  DESCRIPTOR = _ADPARAMETER,
  __module__ = 'google.ads.googleads_v1.proto.resources.ad_parameter_pb2'
  ,
  __doc__ = """An ad parameter that is used to update numeric values (such as prices or
  inventory levels) in any text line of an ad (including URLs). There can
  be a maximum of two AdParameters per ad group criterion. (One with
  parameter\_index = 1 and one with parameter\_index = 2.) In the ad the
  parameters are referenced by a placeholder of the form "{param#:value}".
  E.g. "{param1:$17}"
  
  
  Attributes:
      resource_name:
          The resource name of the ad parameter. Ad parameter resource
          names have the form:  ``customers/{customer_id}/adParameters/{
          ad_group_id}~{criterion_id}~{parameter_index}``
      ad_group_criterion:
          The ad group criterion that this ad parameter belongs to.
      parameter_index:
          The unique index of this ad parameter. Must be either 1 or 2.
      insertion_text:
          Numeric value to insert into the ad text. The following
          restrictions apply: - Can use comma or period as a separator,
          with an optional period or comma (respectively) for fractional
          values. For example, 1,000,000.00 and 2.000.000,10 are valid.
          - Can be prepended or appended with a currency symbol. For
          example, $99.99 is valid. - Can be prepended or appended with
          a currency code. For example, 99.99USD and EUR200 are valid. -
          Can use '%'. For example, 1.0% and 1,0% are valid. - Can use
          plus or minus. For example, -10.99 and 25+ are valid. - Can
          use '/' between two numbers. For example 4/1 and 0.95/0.45 are
          valid.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.AdParameter)
  ))
_sym_db.RegisterMessage(AdParameter)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/enums/vanity_pharma_text.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/enums/vanity_pharma_text.proto',
  package='google.ads.googleads.v1.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v1.enumsB\025VanityPharmaTextProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V1.Enums\312\002\035Google\\Ads\\GoogleAds\\V1\\Enums\352\002!Google::Ads::GoogleAds::V1::Enums'),
  serialized_pb=_b('\n<google/ads/googleads_v1/proto/enums/vanity_pharma_text.proto\x12\x1dgoogle.ads.googleads.v1.enums\x1a\x1cgoogle/api/annotations.proto\"\x8b\x04\n\x14VanityPharmaTextEnum\"\xf2\x03\n\x10VanityPharmaText\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12%\n!PRESCRIPTION_TREATMENT_WEBSITE_EN\x10\x02\x12%\n!PRESCRIPTION_TREATMENT_WEBSITE_ES\x10\x03\x12\"\n\x1ePRESCRIPTION_DEVICE_WEBSITE_EN\x10\x04\x12\"\n\x1ePRESCRIPTION_DEVICE_WEBSITE_ES\x10\x05\x12\x1d\n\x19MEDICAL_DEVICE_WEBSITE_EN\x10\x06\x12\x1d\n\x19MEDICAL_DEVICE_WEBSITE_ES\x10\x07\x12%\n!PREVENTATIVE_TREATMENT_WEBSITE_EN\x10\x08\x12%\n!PREVENTATIVE_TREATMENT_WEBSITE_ES\x10\t\x12)\n%PRESCRIPTION_CONTRACEPTION_WEBSITE_EN\x10\n\x12)\n%PRESCRIPTION_CONTRACEPTION_WEBSITE_ES\x10\x0b\x12#\n\x1fPRESCRIPTION_VACCINE_WEBSITE_EN\x10\x0c\x12#\n\x1fPRESCRIPTION_VACCINE_WEBSITE_ES\x10\rB\xea\x01\n!com.google.ads.googleads.v1.enumsB\x15VanityPharmaTextProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V1.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V1\\Enums\xea\x02!Google::Ads::GoogleAds::V1::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_VANITYPHARMATEXTENUM_VANITYPHARMATEXT = _descriptor.EnumDescriptor(
  name='VanityPharmaText',
  full_name='google.ads.googleads.v1.enums.VanityPharmaTextEnum.VanityPharmaText',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIPTION_TREATMENT_WEBSITE_EN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIPTION_TREATMENT_WEBSITE_ES', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIPTION_DEVICE_WEBSITE_EN', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIPTION_DEVICE_WEBSITE_ES', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEDICAL_DEVICE_WEBSITE_EN', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEDICAL_DEVICE_WEBSITE_ES', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PREVENTATIVE_TREATMENT_WEBSITE_EN', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PREVENTATIVE_TREATMENT_WEBSITE_ES', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIPTION_CONTRACEPTION_WEBSITE_EN', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIPTION_CONTRACEPTION_WEBSITE_ES', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIPTION_VACCINE_WEBSITE_EN', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIPTION_VACCINE_WEBSITE_ES', index=13, number=13,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=151,
  serialized_end=649,
)
_sym_db.RegisterEnumDescriptor(_VANITYPHARMATEXTENUM_VANITYPHARMATEXT)


_VANITYPHARMATEXTENUM = _descriptor.Descriptor(
  name='VanityPharmaTextEnum',
  full_name='google.ads.googleads.v1.enums.VanityPharmaTextEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VANITYPHARMATEXTENUM_VANITYPHARMATEXT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=649,
)

_VANITYPHARMATEXTENUM_VANITYPHARMATEXT.containing_type = _VANITYPHARMATEXTENUM
DESCRIPTOR.message_types_by_name['VanityPharmaTextEnum'] = _VANITYPHARMATEXTENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VanityPharmaTextEnum = _reflection.GeneratedProtocolMessageType('VanityPharmaTextEnum', (_message.Message,), dict(
  DESCRIPTOR = _VANITYPHARMATEXTENUM,
  __module__ = 'google.ads.googleads_v1.proto.enums.vanity_pharma_text_pb2'
  ,
  __doc__ = """The text that will be displayed in display URL of the text ad when
  website description is the selected display mode for vanity pharma URLs.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.enums.VanityPharmaTextEnum)
  ))
_sym_db.RegisterMessage(VanityPharmaTextEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/services/campaign_label_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.resources import campaign_label_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_campaign__label__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/services/campaign_label_service.proto',
  package='google.ads.googleads.v1.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v1.servicesB\031CampaignLabelServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V1.Services\312\002 Google\\Ads\\GoogleAds\\V1\\Services\352\002$Google::Ads::GoogleAds::V1::Services'),
  serialized_pb=_b('\nCgoogle/ads/googleads_v1/proto/services/campaign_label_service.proto\x12 google.ads.googleads.v1.services\x1a<google/ads/googleads_v1/proto/resources/campaign_label.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17google/rpc/status.proto\"0\n\x17GetCampaignLabelRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\xb0\x01\n\x1bMutateCampaignLabelsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12L\n\noperations\x18\x02 \x03(\x0b\x32\x38.google.ads.googleads.v1.services.CampaignLabelOperation\x12\x17\n\x0fpartial_failure\x18\x03 \x01(\x08\x12\x15\n\rvalidate_only\x18\x04 \x01(\x08\"{\n\x16\x43\x61mpaignLabelOperation\x12\x42\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x30.google.ads.googleads.v1.resources.CampaignLabelH\x00\x12\x10\n\x06remove\x18\x02 \x01(\tH\x00\x42\x0b\n\toperation\"\x9f\x01\n\x1cMutateCampaignLabelsResponse\x12\x31\n\x15partial_failure_error\x18\x03 \x01(\x0b\x32\x12.google.rpc.Status\x12L\n\x07results\x18\x02 \x03(\x0b\x32;.google.ads.googleads.v1.services.MutateCampaignLabelResult\"2\n\x19MutateCampaignLabelResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xaa\x03\n\x14\x43\x61mpaignLabelService\x12\xb9\x01\n\x10GetCampaignLabel\x12\x39.google.ads.googleads.v1.services.GetCampaignLabelRequest\x1a\x30.google.ads.googleads.v1.resources.CampaignLabel\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/v1/{resource_name=customers/*/campaignLabels/*}\x12\xd5\x01\n\x14MutateCampaignLabels\x12=.google.ads.googleads.v1.services.MutateCampaignLabelsRequest\x1a>.google.ads.googleads.v1.services.MutateCampaignLabelsResponse\">\x82\xd3\xe4\x93\x02\x38\"3/v1/customers/{customer_id=*}/campaignLabels:mutate:\x01*B\x80\x02\n$com.google.ads.googleads.v1.servicesB\x19\x43\x61mpaignLabelServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V1.Services\xca\x02 Google\\Ads\\GoogleAds\\V1\\Services\xea\x02$Google::Ads::GoogleAds::V1::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_campaign__label__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])




_GETCAMPAIGNLABELREQUEST = _descriptor.Descriptor(
  name='GetCampaignLabelRequest',
  full_name='google.ads.googleads.v1.services.GetCampaignLabelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.GetCampaignLabelRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=254,
  serialized_end=302,
)


_MUTATECAMPAIGNLABELSREQUEST = _descriptor.Descriptor(
  name='MutateCampaignLabelsRequest',
  full_name='google.ads.googleads.v1.services.MutateCampaignLabelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v1.services.MutateCampaignLabelsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v1.services.MutateCampaignLabelsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure', full_name='google.ads.googleads.v1.services.MutateCampaignLabelsRequest.partial_failure', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.ads.googleads.v1.services.MutateCampaignLabelsRequest.validate_only', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=481,
)


_CAMPAIGNLABELOPERATION = _descriptor.Descriptor(
  name='CampaignLabelOperation',
  full_name='google.ads.googleads.v1.services.CampaignLabelOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v1.services.CampaignLabelOperation.create', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v1.services.CampaignLabelOperation.remove', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v1.services.CampaignLabelOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=483,
  serialized_end=606,
)


_MUTATECAMPAIGNLABELSRESPONSE = _descriptor.Descriptor(
  name='MutateCampaignLabelsResponse',
  full_name='google.ads.googleads.v1.services.MutateCampaignLabelsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partial_failure_error', full_name='google.ads.googleads.v1.services.MutateCampaignLabelsResponse.partial_failure_error', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v1.services.MutateCampaignLabelsResponse.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=609,
  serialized_end=768,
)


_MUTATECAMPAIGNLABELRESULT = _descriptor.Descriptor(
  name='MutateCampaignLabelResult',
  full_name='google.ads.googleads.v1.services.MutateCampaignLabelResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.MutateCampaignLabelResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=770,
  serialized_end=820,
)

_MUTATECAMPAIGNLABELSREQUEST.fields_by_name['operations'].message_type = _CAMPAIGNLABELOPERATION
_CAMPAIGNLABELOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_campaign__label__pb2._CAMPAIGNLABEL
_CAMPAIGNLABELOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNLABELOPERATION.fields_by_name['create'])
_CAMPAIGNLABELOPERATION.fields_by_name['create'].containing_oneof = _CAMPAIGNLABELOPERATION.oneofs_by_name['operation']
_CAMPAIGNLABELOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNLABELOPERATION.fields_by_name['remove'])
_CAMPAIGNLABELOPERATION.fields_by_name['remove'].containing_oneof = _CAMPAIGNLABELOPERATION.oneofs_by_name['operation']
_MUTATECAMPAIGNLABELSRESPONSE.fields_by_name['partial_failure_error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_MUTATECAMPAIGNLABELSRESPONSE.fields_by_name['results'].message_type = _MUTATECAMPAIGNLABELRESULT
DESCRIPTOR.message_types_by_name['GetCampaignLabelRequest'] = _GETCAMPAIGNLABELREQUEST
DESCRIPTOR.message_types_by_name['MutateCampaignLabelsRequest'] = _MUTATECAMPAIGNLABELSREQUEST
DESCRIPTOR.message_types_by_name['CampaignLabelOperation'] = _CAMPAIGNLABELOPERATION
DESCRIPTOR.message_types_by_name['MutateCampaignLabelsResponse'] = _MUTATECAMPAIGNLABELSRESPONSE
DESCRIPTOR.message_types_by_name['MutateCampaignLabelResult'] = _MUTATECAMPAIGNLABELRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCampaignLabelRequest = _reflection.GeneratedProtocolMessageType('GetCampaignLabelRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCAMPAIGNLABELREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.campaign_label_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignLabelService.GetCampaignLabel][google.ads.googleads.v1.services.CampaignLabelService.GetCampaignLabel].
  
  
  Attributes:
      resource_name:
          The resource name of the campaign-label relationship to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GetCampaignLabelRequest)
  ))
_sym_db.RegisterMessage(GetCampaignLabelRequest)

MutateCampaignLabelsRequest = _reflection.GeneratedProtocolMessageType('MutateCampaignLabelsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNLABELSREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.campaign_label_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignLabelService.MutateCampaignLabels][google.ads.googleads.v1.services.CampaignLabelService.MutateCampaignLabels].
  
  
  Attributes:
      customer_id:
          ID of the customer whose campaign-label relationships are
          being modified.
      operations:
          The list of operations to perform on campaign-label
          relationships.
      partial_failure:
          If true, successful operations will be carried out and invalid
          operations will return errors. If false, all operations will
          be carried out in one transaction if and only if they are all
          valid. Default is false.
      validate_only:
          If true, the request is validated but not executed. Only
          errors are returned, not results.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateCampaignLabelsRequest)
  ))
_sym_db.RegisterMessage(MutateCampaignLabelsRequest)

CampaignLabelOperation = _reflection.GeneratedProtocolMessageType('CampaignLabelOperation', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNLABELOPERATION,
  __module__ = 'google.ads.googleads_v1.proto.services.campaign_label_service_pb2'
  ,
  __doc__ = """A single operation (create, remove) on a campaign-label relationship.
  
  
  Attributes:
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          campaign-label relationship.
      remove:
          Remove operation: A resource name for the campaign-label
          relationship being removed, in this format:  ``customers/{cust
          omer_id}/campaignLabels/{campaign_id}~{label_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.CampaignLabelOperation)
  ))
_sym_db.RegisterMessage(CampaignLabelOperation)

MutateCampaignLabelsResponse = _reflection.GeneratedProtocolMessageType('MutateCampaignLabelsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNLABELSRESPONSE,
  __module__ = 'google.ads.googleads_v1.proto.services.campaign_label_service_pb2'
  ,
  __doc__ = """Response message for a campaign labels mutate.
  
  
  Attributes:
      partial_failure_error:
          Errors that pertain to operation failures in the partial
          failure mode. Returned only when partial\_failure = true and
          all errors occur inside the operations. If any errors occur
          outside the operations (e.g. auth errors), we return an RPC
          level error.
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateCampaignLabelsResponse)
  ))
_sym_db.RegisterMessage(MutateCampaignLabelsResponse)

MutateCampaignLabelResult = _reflection.GeneratedProtocolMessageType('MutateCampaignLabelResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNLABELRESULT,
  __module__ = 'google.ads.googleads_v1.proto.services.campaign_label_service_pb2'
  ,
  __doc__ = """The result for a campaign label mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateCampaignLabelResult)
  ))
_sym_db.RegisterMessage(MutateCampaignLabelResult)


DESCRIPTOR._options = None

_CAMPAIGNLABELSERVICE = _descriptor.ServiceDescriptor(
  name='CampaignLabelService',
  full_name='google.ads.googleads.v1.services.CampaignLabelService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=823,
  serialized_end=1249,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCampaignLabel',
    full_name='google.ads.googleads.v1.services.CampaignLabelService.GetCampaignLabel',
    index=0,
    containing_service=None,
    input_type=_GETCAMPAIGNLABELREQUEST,
    output_type=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_campaign__label__pb2._CAMPAIGNLABEL,
    serialized_options=_b('\202\323\344\223\0022\0220/v1/{resource_name=customers/*/campaignLabels/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='MutateCampaignLabels',
    full_name='google.ads.googleads.v1.services.CampaignLabelService.MutateCampaignLabels',
    index=1,
    containing_service=None,
    input_type=_MUTATECAMPAIGNLABELSREQUEST,
    output_type=_MUTATECAMPAIGNLABELSRESPONSE,
    serialized_options=_b('\202\323\344\223\0028\"3/v1/customers/{customer_id=*}/campaignLabels:mutate:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_CAMPAIGNLABELSERVICE)

DESCRIPTOR.services_by_name['CampaignLabelService'] = _CAMPAIGNLABELSERVICE

# @@protoc_insertion_point(module_scope)
